# Table of Contents

- [add-relations](<./add-relations.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Add Relations](<./Add-Relations.md>)
  - [Introduction to Relations](<./Add-Relations/Introduction-to-Relations.md>)
  - [Explore Best Practices](<./Add-Relations/Explore-Best-Practices.md>)
  - [Add Relations](<./Add-Relations/Add-Relations.md>)
  - [Monitor Progress Using Metrics](<./Add-Relations/Monitor-Progress-Using-Metrics.md>)
  - [Was this page helpful?](<./Add-Relations/Was-this-page-helpful.md>)
